<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Blog directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2011.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
Name:
	blog_post_short.cfm
Description:
	blog_post_short.cfm
ADF App:
	PT Blog
Version:
	2.0
History:
	2011-10-22 - MFC - App v2.0 release.
	2011-10-28 - MFC - Added Feature - PT tags integration into the blog post.
	2011-11-22 - MFC - Changed the custom metadata form name to "blogs2".
--->
<cfscript>
	// Force dynamic for the TAG ID filters
	request.element.isStatic = 0;
	
	posts = attributes.elementInfo.elementData.propertyValues;
	
	// Get Blog data for the 
	blogData = application.ptBlog2.blogDAO.getBlog(request.page.metadata.blogs2.blogID);
	
	
	// Check if the TAGS ID filter is passed over the URL
	// Set a flag to determine if we run the tag check
	if ( StructKeyExists(request.params, "tagID") AND LEN(request.params.tagID) ){
		// Filter the posts based on the tag ID
		posts = application.ptBlog2.postService.filterPostsDataByTagID(postDataArray=posts, tagID=request.params.tagID);
	}
	
	displayRSSOptions = false;
	// Check if we want to display the RSS options
	if ( StructKeyExists(blogData, "rssFeed") AND (blogData.rssFeed EQ true) )
		displayRSSOptions = true;
	
</cfscript>

<!--- Check if the RSS Feed Option is enabled --->
<cfif displayRSSOptions>
	<!--- RSS Feed Handling --->
	<cfif StructKeyExists(request.params, "rss")>
		<cfset rssStruct = application.ptBlog2.postService.generateRSSFeed(blogDataArray=posts)>
		<!--- // clear the output buffer --->
		<cfset getPageContext().getCFOutput().clearAll()>
		<!--- // turn off cfdebugging --->
		<cfsetting showdebugoutput="no"> 
		<!--- // Generate the RSS feed and output the RSS feed variable. --->
		<cffeed action="create" name="#rssStruct#" overwrite="true" xmlVar="rssXML"> <!---  outputFile="#ExpandPath('/blog1/blogs/rss.xml')#" --->
		<!--- <cfcontent type="text/xml" reset="true"><cfoutput>#rssXML#</cfoutput> --->
		<!--- // Remove all data from the page except the rss feed xml ... Thanks Ben Nadel! --->
		<cfcontent type="text/xml" variable="#toBinary( toBase64( rssXML ))#">	
	</cfif>
</cfif>

<cfoutput>
	<style>
		div.blog-post {
			margin: 20px;
		}
	</style>
	<h2 class="blogs-heading">Latest Blog Posts</h2>
	
	<!--- Check if the RSS Feed Option is enabled --->
	<cfif displayRSSOptions>
		<div><a href="#cgi.URL#?#cgi.QUERY_STRING#&rss=1" target="_blank"><img src="/ADF/apps/pt_blog/images/feed-icon-14x14.png"> RSS Feed</a></div>
	</cfif>
	
	<cfloop from="1" to="#arrayLen(posts)#" index="itm">
		
		<cfif IsNumeric(posts[itm].values.postPageID)>
			<cfscript>
				// Get the comments for the posts
				commentCount = application.ptBlog2.cedata.getCountForElementField(ceName="Comments2", fieldName="postID", fieldValue=posts[itm].values.postID);
				
				// Check if comments are allowed
				if ( posts[itm].values.allowComments EQ 1 )
					renderComments = true;
				else
					renderComments = false;
			</cfscript>
	        
			<div class="blog-post" id="post-#posts[itm].pageID#">
				
				<h3><a class="title" href="#application.ptBlog2.CSData.getCSPageURL(posts[itm].values.postPageID)#" rel="bookmark">#posts[itm].values.title#</a></h3>
				<div class="info">
					<span class="date">#dateFormat(posts[itm].values.datePosted, "mmmm dd, yyyy")#</span>
		
					<!--- Render the comment count if allowed --->
					<cfif renderComments>
						<div class="act">
							<span class="comments">
								<a href="#application.ptBlog2.CSData.getCSPageURL(posts[itm].values.postPageID)###comments" title="Comment on #posts[itm].values.title#">
									#commentCount# Comments
									<!--- No Comments --->
								</a>
							</span>
							<div class="fixed"></div>
						</div>
					</cfif>
					
					<div class="fixed"></div>
				</div>
				<div class="slug">
					<cfif LEN(posts[itm].values.slug)>
						#posts[itm].values.slug#
					</cfif>
					
					<!--- 2011-10-28 - MFC - Added Feature - PT tags integration into the blog post. --->
					<!--- Display the tags for the post --->
					<cfif structKeyExists(posts[itm].values, "tags") and LEN(posts[itm].values.tags)>
						<!--- Check if the PT Tags apps is integrated --->
						<cfif application.ptBlog2.appConfig.tagsIntegrated
								AND ListFindNoCase(application.ADF.siteAppList, "ptTags")>
							
							<!--- Set the blog landing page URL --->
							<cfset blogLandingPageURL = application.ptBlog2.blogService.getFeatureCSPageURL(blogID=blogData.blogID, featureType="landingPage")>
							<!--- // retrieve the names for the tags --->
							<cfset tagNameList = application.ptTags.tagsService.tagNameListByIDs(tagIDList=posts[itm].values.tags, anchorHref=blogLandingPageURL)>
						<cfelse>
							<cfset tagNameList = posts[itm].values.tags>
						</cfif>
						<p class="under"><span class="tags"><strong>Tags:</strong> <em>#replace(tagNameList, "^", ", ", "all")#</em></span></p>
					</cfif>
					<div class="fixed"></div>
				</div>
			</div>
		</cfif>
	</cfloop>
</cfoutput>